"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.subscribeToAssetsBalanceInfo = exports.sortByBalanceAndChainName = exports.isXcmSdkWithdraw = exports.isXcmSdkDeposit = void 0;
function isXcmSdkDeposit(config) {
    return !!config.from;
}
exports.isXcmSdkDeposit = isXcmSdkDeposit;
function isXcmSdkWithdraw(config) {
    return !!config.to;
}
exports.isXcmSdkWithdraw = isXcmSdkWithdraw;
function sortByBalanceAndChainName(a, b) {
    if (a.asset.isNative) {
        return -1;
    }
    if (b.asset.isNative) {
        return 1;
    }
    const aBalance = Number((a.balance * 1000000n) / 10n ** BigInt(a.meta.decimals)) / 1000000;
    const bBalance = Number((b.balance * 1000000n) / 10n ** BigInt(b.meta.decimals)) / 1000000;
    if (aBalance || bBalance) {
        return bBalance - aBalance;
    }
    const aName = (a.origin.name + a.asset.originSymbol).toLowerCase();
    const bName = (b.origin.name + b.asset.originSymbol).toLowerCase();
    if (aName < bName) {
        return -1;
    }
    if (aName > bName) {
        return 1;
    }
    return 0;
}
exports.sortByBalanceAndChainName = sortByBalanceAndChainName;
async function subscribeToAssetsBalanceInfo({ account, polkadot, configBuilder, cb, }) {
    let lastBalance = 0n;
    let lastInfo = [];
    const handler = (data) => {
        const isBalance = typeof data === 'bigint';
        lastBalance = isBalance ? data : lastBalance;
        lastInfo = (isBalance ? lastInfo : data)
            .map((info) => {
            if (info.asset.isNative) {
                // eslint-disable-next-line no-param-reassign
                info.balance = lastBalance;
            }
            return info;
        })
            .sort(sortByBalanceAndChainName);
        cb(lastInfo);
    };
    const unsubscribeBalance = await polkadot.subscribeToBalance(account, handler);
    const unsubscribeInfo = await polkadot.subscribeToAssetsBalanceInfo(account, configBuilder, handler);
    return () => {
        unsubscribeBalance();
        unsubscribeInfo();
    };
}
exports.subscribeToAssetsBalanceInfo = subscribeToAssetsBalanceInfo;
//# sourceMappingURL=sdk.utils.js.map